@@ -32,7 +32,7 @@ class Color:
     light_grey: str = "#727272"
     silver_grey: str = "#8a8a8a"
     white_grey: str = "#bdbdbd"
-    dark_grey: str = "#1A1A1A"
+    dark_grey: str = "#1a1b1b"
     mid_grey_black: str = "#111111"
     light_black: str = "#0e0e0e"
     black: str = "#151515"
@@ -52,12 +52,3 @@ class Font:
     cas10b: str = "Cascadia 10 bold"
     cas11: str = "Cascadia 11"
     cas20b: str = "Cascadia 20 bold"
-
-
-@dataclass(frozen=True, order=True)
-class Misc:
-    """
-    Class for storing misc settings.
-    """
-
-    col58: str = " " * 58
