@@ -5,7 +5,6 @@ from typing import Any, NamedTuple, Union
 from subsearch.data import __data__
 
 
-# update config.json
 def set_config_key_value(key: str, value: Union[str, int, bool]) -> None:
     config_file = f"{__data__}\\config.json"
     with open(config_file, "r+", encoding="utf-8") as f:
@@ -32,7 +31,6 @@ def get_config() -> Any:
     return data
 
 
-# get said value(s) from config.json
 def get_config_key(key: str) -> Any:
     """
     Get values of keys in config.json
@@ -55,8 +53,9 @@ def get_config_key(key: str) -> Any:
     config_json_dict = {
         "current_language": get_config()["current_language"],
         "languages": get_config()["languages"],
-        "hearing_impaired": get_config()["hearing_impaired"],
+        "subtitle_type": get_config()["subtitle_type"],
         "percentage": get_config()["percentage"],
+        "rename_best_match": get_config()["rename_best_match"],
         "context_menu_icon": get_config()["context_menu_icon"],
         "show_download_window": get_config()["show_download_window"],
         "show_terminal": get_config()["show_terminal"],
@@ -70,8 +69,9 @@ def set_default_json() -> None:
     # set default config.json values
     data = get_config()
     data["current_language"] = "English"
-    data["hearing_impaired"] = "Both"
+    data["subtitle_type"] = dict.fromkeys(data["subtitle_type"], True)
     data["percentage"] = 90
+    data["rename_best_match"] = True
     data["context_menu_icon"] = True
     data["show_download_window"] = True
     data["show_terminal"] = False
@@ -86,6 +86,8 @@ def set_default_json() -> None:
 
 class UserParameters(NamedTuple):
     current_language: str
-    hearing_impaired: bool | str
-    pct: int
-    show_dl_window: bool
+    languages: dict[str, str]
+    hearing_impaired: bool
+    non_hearing_impaired: bool
+    percentage: int
+    show_download_window: bool
