@@ -1,21 +1,24 @@
 import re
 from dataclasses import dataclass
-from typing import Any, Literal, Optional, Union
+from typing import Any, Literal, Union
 
+import imdb
 from num2words import num2words
 
+from subsearch.utils.raw_config import UserParameters
 
-def find_year(string: str) -> Union[int, str]:
+
+def find_year(string: str) -> int:
     re_year = re.findall("^.*\.([1-2][0-9]{3})\.", string)  # https://regex101.com/r/r5TwxJ/1
-    if len(re_year) > 0:
+    if re_year:
         year = re_year[0]
         return int(year)
-    return "N/A"
+    return 0000
 
 
 def find_title_by_year(string: str) -> str:
     re_title = re.findall("^(.*)\.[1-2][0-9]{3}\.", string)  # https://regex101.com/r/FKUpY0/1
-    if len(re_title) > 0:
+    if re_title:
         title: str = re_title[0]
         title = title.replace(".", " ")
         return title
@@ -24,7 +27,7 @@ def find_title_by_year(string: str) -> str:
 
 def find_title_by_show(string: str) -> str:
     re_title = re.findall("^(.*)\.[s]\d*[e]\d*\.", string)  # https://regex101.com/r/41OZE5/1
-    if len(re_title) > 0:
+    if re_title:
         title: str = re_title[0]
         title = title.replace(".", " ")
         return title
@@ -33,27 +36,22 @@ def find_title_by_show(string: str) -> str:
 
 def find_season_episode(string: str) -> str:
     re_se = re.findall("\.([s]\d*[e]\d*)\.", string)  # https://regex101.com/r/8Nwlr6/1
-    if len(re_se) > 0:
+    if re_se:
         se: str = re_se[0]
         return se
     return "N/A"
 
 
-NA = tuple[Literal["N/A"], Literal["N/A"], Literal["N/A"], Literal["N/A"], Literal[False]]
-
-
-def find_ordinal(string: str) -> Union[tuple[str, str, str, str, bool], NA]:
+def find_ordinal(string: str) -> tuple[str, str, str, str, bool]:
     if string == "N/A":
         season, season_ordinal, episode, episode_ordinal = "N/A", "N/A", "N/A", "N/A"
         show_bool = False
-
-        return season, season_ordinal, episode, episode_ordinal, show_bool
     else:
         season, episode = string.replace("s", "").replace("e", " ").split(" ")
         season_ordinal = num2words(int(season), lang="en", to="ordinal")
         episode_ordinal = num2words(int(episode), lang="en", to="ordinal")
         show_bool = True
-        return season, season_ordinal, episode, episode_ordinal, show_bool
+    return season, season_ordinal, episode, episode_ordinal, show_bool
 
 
 def find_group(string: str) -> str:
@@ -61,8 +59,21 @@ def find_group(string: str) -> str:
     return group
 
 
-def rpl_sp_pct20(x: str) -> str:
-    return x.replace(" ", "%20")
+def find_imdb_tt_id(base_yts: str, title: str, year: int) -> str:
+    ia = imdb.Cinemagoer()
+    movies = ia.search_movie(title)
+    url_yifysubtitles = base_yts
+    for movie in movies:
+        movie_no_colon = movie.data["title"].replace(":", "").split("(")[0]
+        if movie_no_colon.lower() != title.lower():
+            continue
+        if movie.data["year"] != year and movie.data["year"] != year - 1:
+            continue
+        _movie_id: str = movie.movieID
+        tt_id = f"tt{_movie_id}"
+        url_yifysubtitles = f"{base_yts}/{tt_id}"
+        break
+    return url_yifysubtitles
 
 
 @dataclass(frozen=True, order=True)
@@ -70,8 +81,9 @@ class FileSearchParameters:
     url_subscene: str
     url_opensubtitles: str
     url_opensubtitles_hash: str
+    url_yifysubtitles: str
     title: str
-    year: Union[int, str]
+    year: int
     season: str
     season_ordinal: str
     episode: str
@@ -79,13 +91,11 @@ class FileSearchParameters:
     series: bool
     release: str
     group: str
-    file_hash: Optional[str]
+    file_hash: str
     definitive_match: str
 
 
-def get_parameters(
-    filename: str, file_hash: Optional[str], current_language: str, languages: dict[str, str]
-) -> FileSearchParameters:
+def get_parameters(filename: str, file_hash: str, user_parameters: UserParameters) -> FileSearchParameters:
     """
     Parse filename and get parameters for searching on subscene and opensubtitles
     Uses regex expressions to find the parameters
@@ -99,14 +109,15 @@ def get_parameters(
         SearchParameters: title, year, season, season_ordinal, episode, episode_ordinal, tv_series, release, group
     """
     filename = filename.lower()
-    lang_code3 = languages[current_language]
+
+    lang_code3 = user_parameters.languages[user_parameters.current_language]
     year = find_year(filename)
     season_episode = find_season_episode(filename)
     season, season_ordinal, episode, episode_ordinal, series = find_ordinal(season_episode)
 
-    if year != "N/A":
+    if year != 0000:
         title = find_title_by_year(filename)
-    elif series and year == "N/A":
+    elif series and year == 0000:
         title = find_title_by_show(filename)
     else:
         title = filename.rsplit("-", 1)[0]
@@ -114,15 +125,23 @@ def get_parameters(
     group = find_group(filename)
 
     base_ss = "https://subscene.com/subtitles/searchbytitle?query="
-    base_os = f"https://www.opensubtitles.org/en/search/sublanguageid-{lang_code3}"
+    base_yts = "https://yifysubtitles.org/movie-imdb"
+
+    if user_parameters.hearing_impaired and user_parameters.non_hearing_impaired is False:
+        base_os = f"https://www.opensubtitles.org/en/search/sublanguageid-{lang_code3}/hearingimpaired-on"
+    else:
+        base_os = f"https://www.opensubtitles.org/en/search/sublanguageid-{lang_code3}"
+
     url_opensubtitles_hash = f"{base_os}/moviehash-{file_hash}"
 
     if series:
         url_subscene = f"{base_ss}{title} - {season_ordinal} season"
         url_opensubtitles = f"{base_os}/searchonlytvseries-on/season-{season}/episode-{episode}/moviename-{title}/rss_2_00"
+        url_yifysubtitles = "N/A"
     else:
         url_subscene = f"{base_ss}{title} ({year})"
         url_opensubtitles = f"{base_os}/searchonlymovies-on/moviename-{title} ({year})/rss_2_00"
+        url_yifysubtitles = find_imdb_tt_id(base_yts, title, year)
 
     definitive_match = url_subscene.rsplit("query=", 1)[-1]
 
@@ -133,6 +152,7 @@ def get_parameters(
         url_subscene,
         url_opensubtitles,
         url_opensubtitles_hash,
+        url_yifysubtitles,
         title,
         year,
         season,
